@@ -1,5 +1,5 @@
 /*
- * $Id: cap_sys.c,v 1.2 1997/04/28 00:57:11 morgan Exp morgan $
+ * $Id: cap_sys.c,v 1.1.1.1 1999/04/17 22:16:31 morgan Exp $
  *
  * Copyright (c) 1997-8 Andrew G. Morgan   <morgan@linux.kernel.org>
  *
@@ -8,6 +8,7 @@
  */
 
 #include "libcap.h"
+#define __LIBRARY__
 #include <linux/unistd.h>
 
 _syscall2(int, capget,
@@ -20,6 +21,15 @@ _syscall2(int, capset,
 
 /*
  * $Log: cap_sys.c,v $
+ * Revision 1.1.1.1  1999/04/17 22:16:31  morgan
+ * release 1.0 of libcap
+ *
+ * Revision 1.4  1998/06/08 00:14:01  morgan
+ * change to accommodate alpha (glibc?)
+ *
+ * Revision 1.3  1998/05/24 22:54:09  morgan
+ * updated for 2.1.104
+ *
  * Revision 1.2  1997/04/28 00:57:11  morgan
  * fixes and zefram's patches
  *
